*********************
*** CLEANING DATA ***		    
*********************



**# Part 1: First period (1877-1879)

//	Importing processed data from Excel for the period 1877-1879
clear all
cd "Your preferred location"
import excel "Your preferred location\Database_IMR_NL_1878_1909.xlsx", sheet("Processed Data") cellrange(A2:Q1130) firstrow

// 	Dropping the municipalities of Anna Paulowna and Zijpe 
drop if acode == 10004
drop if acode == 10344

//	Indicating missing and unknown values
replace ilg_b = . if ilg_b < -0.000000000000001
replace vacc = . if vacc < -0.000000000000001
replace rec_vacc = . if rec_vacc < -0.000000000000001

//	Destringing the variable prov and setting the province of Gelderland as the reference category
rename prov prov_DEL
encode prov_DEL, gen(prov)
drop prov_DEL
fvset base 3 prov
codebook prov, tabulate(11)

//	Labeling of the variables
label variable acode "Amsterdam Code"
label variable prov "Name of the province"
label variable IMR "Infant Mortality Rate"
label variable ilg_b "Illegitimate births (%)"
label variable GFR "General Fertility Rate: Number of live Births per 100 women"
label variable f_lbr "Female labour participation (%)"
label variable cath "Catholics (%)"
label variable ortx_prt "Orthodox protestants (%)"
label variable jews "Jews (%)"
label variable urbn "Urbanisation: Logarithm of the population density"
label variable soil "Main soil type of the municipality"
label variable WPS "Presence of a Water Pipe Supply"
label variable med_dr "Medical doctors per 1,000 inhabitants"
label variable srgn "Town and country surgeons per 1,000 inhabitants"
label variable midw "Midwives per 1,000 inhabitants"
label variable vacc "Vaccination rate (%)"
label variable rec_vacc "Recent vaccination rate (%)"

// Descriptive statistics
sum

//	Dropping incomplete variables
drop ilg_b vacc prov

//	Saving the clean data for the period 1877-1879
export excel using "1877-1879 Data Merge", sheet("1877-1879") firstrow(variables) replace






**# Part 2: Second period (1908-1910)

//	Importing processed data from Excel for the period 1908-1910
clear all
cd "Your preferred location"
import excel "Your preferred location\Database_IMR_NL_1878_1909.xlsx", sheet("Processed Data") cellrange(S2:AG1123) firstrow

//	Indicating missing and unknown values
replace rec_vacc = . if rec_vacc < -0.000000000000001

//	Destringing the variable prov and setting the province of Gelderland as the reference category
rename prov prov_DEL
encode prov_DEL, gen(prov)
drop prov_DEL
fvset base 3 prov
codebook prov, tabulate(11)

//	Labeling of the variables
label variable acode "Amsterdam Code"
label variable prov "Name of the province"
label variable IMR "Infant Mortality Rate"
label variable ilg_b "Illegitimate births (%)"
label variable GFR "General Fertility Rate: Number of live Births per 100 women"
label variable f_lbr "Female labour participation (%)"
label variable cath "Catholics (%)"
label variable ortx_prt "Orthodox protestants (%)"
label variable jews "Jews (%)"
label variable urbn "Urbanisation: Logarithm of the population density"
label variable soil "Soil type of the municipality"
label variable WPS "Presence of a Water Pipe Supply"
label variable phys "Physicians per 1,000 inhabitants"
label variable nurses "Nurses per 1,000 inhabitants"
label variable rec_vacc "Recent vaccination rate (%)"

// Descriptive statistics
sum

//	Dropping irrelevant variables
drop rec_vacc prov

//	Saving the clean data for the period 1877-1879
export excel using "1908-1910 Data Merge", sheet("1908-1910") firstrow(variables) replace